import pandas as pd
import ast

class DataPreprocessor:
    """
    output klasöründe bulunan birlesik_veri.csf dosyası işlemden geçirilir ve output.csv olarak pd.DataFrame olarak
    output klasörüğnde saklanır
    """
    def __init__(self, file_path):
        self.file_path = file_path
        self.data = pd.read_csv(file_path)
        self.data[["tez_no", "yıl"]] = self.data[["tez_no", "yıl"]].astype(int)
        
    def process_text_abs(self, text):
        try:
            data = ast.literal_eval(text.replace('\x00', ''))
            return pd.Series({'tr': data['tr'], 'en': data['en']})
        except:
            return pd.Series({'tr': '', 'en': ''})
        
    def preprocess_abstracts(self):
        processed_abs = self.data["tr_en"].apply(self.process_text_abs)
        df = pd.concat([self.data, processed_abs], axis=1)
        df['tr'] = df['tr'].str.strip('\n\t ')
        df['en'] = df['en'].str.strip('\n\t ')
        self.data = df.drop(["tr_en"], axis=1)
        
    def process_text_titel(self, text):
        try:
            data = ast.literal_eval(text.replace('\x00', ''))
            return pd.Series({'tr_titel': data['tr'], 'en_titel': data['en']})
        except:
            return pd.Series({'tr_titel': '', 'en_titel': ''})
        
    def preprocess_titles(self):
        processed_titel = self.data["tez_adı"].apply(self.process_text_titel)
        df = pd.concat([self.data, processed_titel], axis=1)
        self.data = df.drop(["tez_adı"], axis=1)
        
    def rename_columns(self):
        self.data.rename(columns={'tez_no': "no", 'yazar': "author", 'yıl': "year", 'üniversite': "university",
                                  'tez_türü': "type", 'konu': "field", 'tr': "tr_abs", 'en': "en_abs",
                                  'tr_titel': "tr_title", 'en_titel': "en_title"}, inplace=True)
        
    def save_processed_data(self):
        self.data.to_csv("output/output.csv", index=False)
    
    def run(self):
        #self.process_text_abs()
        self.preprocess_abstracts()
        #self.process_text_titel()
        self.preprocess_titles()
        self.rename_columns()
        self.save_processed_data()

        
# Veri işleme işlemi için bir DataPreprocessor nesnesi oluşturun
# processor = DataPreprocessor("input.csv")

# Veriyi işle ve sonucu belirtilen çıkış yoluna kaydet
# processor.run("output.csv")


